# Welcome

Source at [https://github.com/thenoursehorse/risb](https://github.com/thenoursehorse/risb)

:::{include} ../README.md
:start-after: <!-- INDEX-START -->
:end-before: <!-- INDEX-END -->
:::

```{toctree}
:hidden:

install
about
how-to/index
tutorials/index
explanations/index
```

```{toctree}
:caption: API Docs
:hidden:
 
api/risb
```

## Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`